from django.apps import AppConfig


class BootstrapThemeConfig(AppConfig):
    name = "bootswatch.theme.minty"
    label = "minty"
    version = "5.3.3"
    verbose_name = f"Minty v{version}"

    def ready(self):
        pass



from allianceauth import hooks
from allianceauth.theme.hooks import ThemeHook


class SolarThemeHook(ThemeHook):
    """
    Bootswatch Solar Theme
    https://bootswatch.com/solar/
    """

    def __init__(self) -> None:
        ThemeHook.__init__(
            self=self,
            name="Solar",
            description="A spin on Solarized",
            html_tags={"data-theme": "solar"},
            css=[
                {
                    "url": "https://cdnjs.cloudflare.com/ajax/libs/bootswatch/5.3.3/solar/bootstrap.min.css",
                    "integrity": "sha512-0BjJSwKzc+sx3vM/B9nEU98M/hCLM2bcIWrzGe9fqJZFVicDjxu2vrHd0/7ildD+23p5JsQNo8IEL+sOb+A1iw==",
                }
            ],
            js=[
                {
                    "url": "https://cdnjs.cloudflare.com/ajax/libs/popper.js/2.11.8/umd/popper.min.js",
                    "integrity": "sha512-TPh2Oxlg1zp+kz3nFA0C5vVC6leG/6mm1z9+mA81MI5eaUVqasPLO8Cuk4gMF4gUfP5etR73rgU/8PNMsSesoQ==",
                },
                {
                    "url": "https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.3.3/js/bootstrap.min.js",
                    "integrity": "sha512-ykZ1QQr0Jy/4ZkvKuqWn4iF3lqPZyij9iRv6sGqLRdTPkY69YX6+7wvVGmsdBbiIfN/8OdsI7HABjvEok6ZopQ==",
                },
            ],
            header_padding="3.5em",
        )


@hooks.register("theme_hook")
def register_solar_hook() -> SolarThemeHook:
    return SolarThemeHook()



from django.apps import AppConfig


class BootstrapThemeConfig(AppConfig):
    name = "bootswatch.theme.united"
    label = "united"
    version = "5.3.3"
    verbose_name = f"United v{version}"

    def ready(self):
        pass



from allianceauth import hooks
from allianceauth.theme.hooks import ThemeHook


class SketchyThemeHook(ThemeHook):
    """
    Bootswatch Sketchy Theme
    https://bootswatch.com/sketchy/
    """

    def __init__(self) -> None:
        ThemeHook.__init__(
            self=self,
            name="Sketchy",
            description="A hand-drawn look for mockups and mirth",
            html_tags={"data-theme": "sketchy"},
            css=[
                {
                    "url": "https://cdnjs.cloudflare.com/ajax/libs/bootswatch/5.3.3/sketchy/bootstrap.min.css",
                    "integrity": "sha512-y4F259NzBXkxhixXEuh574bj6TdXVeS6RX+2x9wezULTmAOSgWCm25a+6d0IQxAnbg+D4xIEJoll8piTADM5Gg==",
                }
            ],
            js=[
                {
                    "url": "https://cdnjs.cloudflare.com/ajax/libs/popper.js/2.11.8/umd/popper.min.js",
                    "integrity": "sha512-TPh2Oxlg1zp+kz3nFA0C5vVC6leG/6mm1z9+mA81MI5eaUVqasPLO8Cuk4gMF4gUfP5etR73rgU/8PNMsSesoQ==",
                },
                {
                    "url": "https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.3.3/js/bootstrap.min.js",
                    "integrity": "sha512-ykZ1QQr0Jy/4ZkvKuqWn4iF3lqPZyij9iRv6sGqLRdTPkY69YX6+7wvVGmsdBbiIfN/8OdsI7HABjvEok6ZopQ==",
                },
            ],
            header_padding="3.6em",
        )


@hooks.register("theme_hook")
def register_sketchy_hook() -> SketchyThemeHook:
    return SketchyThemeHook()



from allianceauth import hooks
from allianceauth.theme.hooks import ThemeHook


class SpacelabThemeHook(ThemeHook):
    """
    Bootswatch Spacelab Theme
    https://bootswatch.com/spacelab/
    """

    def __init__(self) -> None:
        ThemeHook.__init__(
            self=self,
            name="Spacelab",
            description="Silvery and sleek",
            html_tags={"data-theme": "spacelab"},
            css=[
                {
                    "url": "https://cdnjs.cloudflare.com/ajax/libs/bootswatch/5.3.3/spacelab/bootstrap.min.css",
                    "integrity": "sha512-NWw8XgTx2tYA5oEZwBrmyH8bg37mh4bIjeV4OLWwqI3ipQ0ITyiWTFdG295uz2lMy+QO9DszNZwta4m4mJpnmw==",
                }
            ],
            js=[
                {
                    "url": "https://cdnjs.cloudflare.com/ajax/libs/popper.js/2.11.8/umd/popper.min.js",
                    "integrity": "sha512-TPh2Oxlg1zp+kz3nFA0C5vVC6leG/6mm1z9+mA81MI5eaUVqasPLO8Cuk4gMF4gUfP5etR73rgU/8PNMsSesoQ==",
                },
                {
                    "url": "https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.3.3/js/bootstrap.min.js",
                    "integrity": "sha512-ykZ1QQr0Jy/4ZkvKuqWn4iF3lqPZyij9iRv6sGqLRdTPkY69YX6+7wvVGmsdBbiIfN/8OdsI7HABjvEok6ZopQ==",
                },
            ],
            header_padding="3.6em",
        )


@hooks.register("theme_hook")
def register_spacelab_hook() -> SpacelabThemeHook:
    return SpacelabThemeHook()



from allianceauth import hooks
from allianceauth.theme.hooks import ThemeHook


class UnitedThemeHook(ThemeHook):
    """
    Bootswatch United Theme
    https://bootswatch.com/united/
    """

    def __init__(self) -> None:
        ThemeHook.__init__(
            self=self,
            name="United",
            description="Ubuntu orange and unique font",
            html_tags={"data-theme": "united"},
            css=[
                {
                    "url": "https://cdnjs.cloudflare.com/ajax/libs/bootswatch/5.3.3/united/bootstrap.min.css",
                    "integrity": "sha512-bDf5pNGht0HBv1tNSyB06LQ4D+5IV4xpCmAFKORMIQi57c8mq96hg2Wa03//JNjHEjEai1qV+ZOUcwuy70j02A==",
                }
            ],
            js=[
                {
                    "url": "https://cdnjs.cloudflare.com/ajax/libs/popper.js/2.11.8/umd/popper.min.js",
                    "integrity": "sha512-TPh2Oxlg1zp+kz3nFA0C5vVC6leG/6mm1z9+mA81MI5eaUVqasPLO8Cuk4gMF4gUfP5etR73rgU/8PNMsSesoQ==",
                },
                {
                    "url": "https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.3.3/js/bootstrap.min.js",
                    "integrity": "sha512-ykZ1QQr0Jy/4ZkvKuqWn4iF3lqPZyij9iRv6sGqLRdTPkY69YX6+7wvVGmsdBbiIfN/8OdsI7HABjvEok6ZopQ==",
                },
            ],
            header_padding="3.5em",
        )


@hooks.register("theme_hook")
def register_united_hook() -> UnitedThemeHook:
    return UnitedThemeHook()
